.. _spider_openwrt.org:

openwrt.org
-----------
Newest releases from `OpenWRT <https://openwrt.org>`_.

Configuration
~~~~~~~~~~~~~
Add ``openwrt.org`` to the list of spiders:

.. code-block:: ini

   # List of spiders to run by default, one per line.
   spiders =
     openwrt.org

